=======
Credits
=======

Development Lead
----------------

- Joel Akeret (ETHZ)
- Sebastian Seehars (ETHZ)

Contributors
------------

None yet. Why not be the first?

Citations
---------

As you use **CosmoHammer** for your exciting discoveries, please cite the paper that describes the package: 

Akeret, J., Seehars, S., Amara, A, Refregier, A., and Csillaghy, A., Astronomy and Computing (2013)
